Binary

Trait Binary 

1.0.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize

Source

impl Binary for bf16

Source

impl Binary for f16

Source

impl Binary for BigInt

Source

impl Binary for BigUint

Source

impl Binary for CipherCtxFlags

Source

impl Binary for CMSOptions

Source

impl Binary for OcspFlag

Source

impl Binary for Pkcs7Flags

Source

impl Binary for ExtensionContext

Source

impl Binary for ShutdownState

Source

impl Binary for SslMode

Source

impl Binary for SslOptions

Source

impl Binary for SslSessionCacheMode

Source

impl Binary for SslVerifyMode

Source

impl Binary for X509CheckFlags

Source

impl Binary for X509VerifyFlags



impl Binary for Access



impl Binary for AccessFlags



impl Binary for AtFlags



impl Binary for AtFlags



impl Binary for ControlFlags



impl Binary for ControlModes



impl Binary for CreateFlags



impl Binary for CreateFlags



impl Binary for DupFlags



impl Binary for EventFlags



impl Binary for EventfdFlags



impl Binary for FallocateFlags



impl Binary for FallocateFlags



impl Binary for FdFlag



impl Binary for FdFlags



impl Binary for FloatingPointEmulationControl



impl Binary for FloatingPointExceptionMode



impl Binary for FsFlags



impl Binary for IFlags



impl Binary for InputFlags



impl Binary for InputModes



impl Binary for LocalFlags



impl Binary for LocalModes



impl Binary for MFdFlags



impl Binary for MembarrierQuery



impl Binary for MemfdFlags



impl Binary for MetaCharType



impl Binary for Mode



impl Binary for Mode



impl Binary for Modifiers



impl Binary for MountFlags



impl Binary for MountPropagationFlags



impl Binary for OFlag



impl Binary for OFlags



impl Binary for OutputFlags



impl Binary for OutputModes



impl Binary for PidfdFlags



impl Binary for PidfdGetfdFlags



impl Binary for PipeFlags



impl Binary for PollFlags



impl Binary for PollFlags



impl Binary for PosixSpawnFlags



impl Binary for ReadFlags



impl Binary for ReadWriteFlags



impl Binary for RecvFlags



impl Binary for RegexOptions



impl Binary for RenameFlags



impl Binary for RenameFlags



impl Binary for ResolveFlag



impl Binary for ResolveFlags



impl Binary for SFlag



impl Binary for SaFlags



impl Binary for SealFlag



impl Binary for SealFlags



impl Binary for SearchOptions



impl Binary for SendFlags



impl Binary for SfdFlags



impl Binary for SockaddrXdpFlags



impl Binary for SocketFlags



impl Binary for SpeculationFeatureControl



impl Binary for SpeculationFeatureState



impl Binary for SpliceFlags



impl Binary for StatVfsMountFlags



impl Binary for StatxFlags



impl Binary for SyntaxBehavior



impl Binary for SyntaxOperator



impl Binary for TimerfdFlags



impl Binary for TimerfdTimerFlags



impl Binary for TraverseCallbackAt



impl Binary for UnalignedAccessControl



impl Binary for UnmountFlags



impl Binary for WaitOptions



impl Binary for WaitPidFlag



impl Binary for WaitidOptions



impl Binary for WatchFlags



impl Binary for XattrFlags



impl Binary for XdpDescOptions



impl Binary for XdpOptionsFlags



impl Binary for XdpRingFlags



impl Binary for XdpUmemRegFlags



impl<'a, Color, T> Binary for BgColorDisplay<'a, Color, T>
where Color: Color, T: Binary + ?Sized,



impl<'a, Color, T> Binary for BgDynColorDisplay<'a, Color, T>
where Color: DynColor, T: Binary + ?Sized,



impl<'a, Color, T> Binary for FgColorDisplay<'a, Color, T>
where Color: Color, T: Binary + ?Sized,



impl<'a, Color, T> Binary for FgDynColorDisplay<'a, Color, T>
where Color: DynColor, T: Binary + ?Sized,



impl<'a, Fg, Bg, T> Binary for ComboColorDisplay<'a, Fg, Bg, T>
where Fg: Color, Bg: Color, T: Binary + ?Sized,



impl<'a, Fg, Bg, T> Binary for ComboDynColorDisplay<'a, Fg, Bg, T>
where Fg: DynColor, Bg: DynColor, T: Binary + ?Sized,



impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,



impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,



impl<'a, In, Out, F> Binary for SupportsColorsDisplay<'a, In, Out, F>
where In: Binary, Out: Binary, F: Fn(&'a In) -> Out,



impl<'a, T> Binary for BlinkDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for BlinkFastDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for BoldDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for DimDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for HiddenDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for ItalicDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for ReversedDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for StrikeThroughDisplay<'a, T>
where T: Binary + ?Sized,



impl<'a, T> Binary for UnderlineDisplay<'a, T>
where T: Binary + ?Sized,



impl<O> Binary for I16<O>
where O: ByteOrder,



impl<O> Binary for I32<O>
where O: ByteOrder,



impl<O> Binary for I64<O>
where O: ByteOrder,



impl<O> Binary for I128<O>
where O: ByteOrder,



impl<O> Binary for Isize<O>
where O: ByteOrder,



impl<O> Binary for U16<O>
where O: ByteOrder,



impl<O> Binary for U32<O>
where O: ByteOrder,



impl<O> Binary for U64<O>
where O: ByteOrder,



impl<O> Binary for U128<O>
where O: ByteOrder,



impl<O> Binary for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

1.28.0 · Source

impl<T> Binary for NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for Wrapping<T>
where T: Binary,

Source

impl<T> Binary for Complex<T>
where T: Binary + Num + PartialOrd + Clone,

Source

impl<T> Binary for Ratio<T>
where T: Binary + Clone + Integer,



impl<T> Binary for Styled<T>
where T: Binary,



impl<const MIN: i8, const MAX: i8> Binary for RangedI8<MIN, MAX>



impl<const MIN: i16, const MAX: i16> Binary for RangedI16<MIN, MAX>



impl<const MIN: i32, const MAX: i32> Binary for RangedI32<MIN, MAX>



impl<const MIN: i64, const MAX: i64> Binary for RangedI64<MIN, MAX>



impl<const MIN: i128, const MAX: i128> Binary for RangedI128<MIN, MAX>



impl<const MIN: isize, const MAX: isize> Binary for RangedIsize<MIN, MAX>



impl<const MIN: u8, const MAX: u8> Binary for RangedU8<MIN, MAX>



impl<const MIN: u16, const MAX: u16> Binary for RangedU16<MIN, MAX>



impl<const MIN: u32, const MAX: u32> Binary for RangedU32<MIN, MAX>



impl<const MIN: u64, const MAX: u64> Binary for RangedU64<MIN, MAX>



impl<const MIN: u128, const MAX: u128> Binary for RangedU128<MIN, MAX>



impl<const MIN: usize, const MAX: usize> Binary for RangedUsize<MIN, MAX>