Octal

Trait Octal 

1.0.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize

Source

impl Octal for bf16

Source

impl Octal for f16

Source

impl Octal for BigInt

Source

impl Octal for BigUint

Source

impl Octal for CipherCtxFlags

Source

impl Octal for CMSOptions

Source

impl Octal for OcspFlag

Source

impl Octal for Pkcs7Flags

Source

impl Octal for ExtensionContext

Source

impl Octal for ShutdownState

Source

impl Octal for SslMode

Source

impl Octal for SslOptions

Source

impl Octal for SslSessionCacheMode

Source

impl Octal for SslVerifyMode

Source

impl Octal for X509CheckFlags

Source

impl Octal for X509VerifyFlags



impl Octal for Access



impl Octal for AccessFlags



impl Octal for AtFlags



impl Octal for AtFlags



impl Octal for ControlFlags



impl Octal for ControlModes



impl Octal for CreateFlags



impl Octal for CreateFlags



impl Octal for DupFlags



impl Octal for EventFlags



impl Octal for EventfdFlags



impl Octal for FallocateFlags



impl Octal for FallocateFlags



impl Octal for FdFlag



impl Octal for FdFlags



impl Octal for FloatingPointEmulationControl



impl Octal for FloatingPointExceptionMode



impl Octal for FsFlags



impl Octal for IFlags



impl Octal for InputFlags



impl Octal for InputModes



impl Octal for LocalFlags



impl Octal for LocalModes



impl Octal for MFdFlags



impl Octal for MembarrierQuery



impl Octal for MemfdFlags



impl Octal for MetaCharType



impl Octal for Mode



impl Octal for Mode



impl Octal for Modifiers



impl Octal for MountFlags



impl Octal for MountPropagationFlags



impl Octal for OFlag



impl Octal for OFlags



impl Octal for OutputFlags



impl Octal for OutputModes



impl Octal for PidfdFlags



impl Octal for PidfdGetfdFlags



impl Octal for PipeFlags



impl Octal for PollFlags



impl Octal for PollFlags



impl Octal for PosixSpawnFlags



impl Octal for ReadFlags



impl Octal for ReadWriteFlags



impl Octal for RecvFlags



impl Octal for RegexOptions



impl Octal for RenameFlags



impl Octal for RenameFlags



impl Octal for ResolveFlag



impl Octal for ResolveFlags



impl Octal for SFlag



impl Octal for SaFlags



impl Octal for SealFlag



impl Octal for SealFlags



impl Octal for SearchOptions



impl Octal for SendFlags



impl Octal for SfdFlags



impl Octal for SockaddrXdpFlags



impl Octal for SocketFlags



impl Octal for SpeculationFeatureControl



impl Octal for SpeculationFeatureState



impl Octal for SpliceFlags



impl Octal for StatVfsMountFlags



impl Octal for StatxFlags



impl Octal for SyntaxBehavior



impl Octal for SyntaxOperator



impl Octal for TimerfdFlags



impl Octal for TimerfdTimerFlags



impl Octal for TraverseCallbackAt



impl Octal for UnalignedAccessControl



impl Octal for UnmountFlags



impl Octal for WaitOptions



impl Octal for WaitPidFlag



impl Octal for WaitidOptions



impl Octal for WatchFlags



impl Octal for XattrFlags



impl Octal for XdpDescOptions



impl Octal for XdpOptionsFlags



impl Octal for XdpRingFlags



impl Octal for XdpUmemRegFlags



impl<'a, Color, T> Octal for BgColorDisplay<'a, Color, T>
where Color: Color, T: Octal + ?Sized,



impl<'a, Color, T> Octal for BgDynColorDisplay<'a, Color, T>
where Color: DynColor, T: Octal + ?Sized,



impl<'a, Color, T> Octal for FgColorDisplay<'a, Color, T>
where Color: Color, T: Octal + ?Sized,



impl<'a, Color, T> Octal for FgDynColorDisplay<'a, Color, T>
where Color: DynColor, T: Octal + ?Sized,



impl<'a, Fg, Bg, T> Octal for ComboColorDisplay<'a, Fg, Bg, T>
where Fg: Color, Bg: Color, T: Octal + ?Sized,



impl<'a, Fg, Bg, T> Octal for ComboDynColorDisplay<'a, Fg, Bg, T>
where Fg: DynColor, Bg: DynColor, T: Octal + ?Sized,



impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,



impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,



impl<'a, In, Out, F> Octal for SupportsColorsDisplay<'a, In, Out, F>
where In: Octal, Out: Octal, F: Fn(&'a In) -> Out,



impl<'a, T> Octal for BlinkDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for BlinkFastDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for BoldDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for DimDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for HiddenDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for ItalicDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for ReversedDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for StrikeThroughDisplay<'a, T>
where T: Octal + ?Sized,



impl<'a, T> Octal for UnderlineDisplay<'a, T>
where T: Octal + ?Sized,



impl<O> Octal for I16<O>
where O: ByteOrder,



impl<O> Octal for I32<O>
where O: ByteOrder,



impl<O> Octal for I64<O>
where O: ByteOrder,



impl<O> Octal for I128<O>
where O: ByteOrder,



impl<O> Octal for Isize<O>
where O: ByteOrder,



impl<O> Octal for U16<O>
where O: ByteOrder,



impl<O> Octal for U32<O>
where O: ByteOrder,



impl<O> Octal for U64<O>
where O: ByteOrder,



impl<O> Octal for U128<O>
where O: ByteOrder,



impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

1.28.0 · Source

impl<T> Octal for NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for Wrapping<T>
where T: Octal,

Source

impl<T> Octal for Complex<T>
where T: Octal + Num + PartialOrd + Clone,

Source

impl<T> Octal for Ratio<T>
where T: Octal + Clone + Integer,



impl<T> Octal for Styled<T>
where T: Octal,



impl<const MIN: i8, const MAX: i8> Octal for RangedI8<MIN, MAX>



impl<const MIN: i16, const MAX: i16> Octal for RangedI16<MIN, MAX>



impl<const MIN: i32, const MAX: i32> Octal for RangedI32<MIN, MAX>



impl<const MIN: i64, const MAX: i64> Octal for RangedI64<MIN, MAX>



impl<const MIN: i128, const MAX: i128> Octal for RangedI128<MIN, MAX>



impl<const MIN: isize, const MAX: isize> Octal for RangedIsize<MIN, MAX>



impl<const MIN: u8, const MAX: u8> Octal for RangedU8<MIN, MAX>



impl<const MIN: u16, const MAX: u16> Octal for RangedU16<MIN, MAX>



impl<const MIN: u32, const MAX: u32> Octal for RangedU32<MIN, MAX>



impl<const MIN: u64, const MAX: u64> Octal for RangedU64<MIN, MAX>



impl<const MIN: u128, const MAX: u128> Octal for RangedU128<MIN, MAX>



impl<const MIN: usize, const MAX: usize> Octal for RangedUsize<MIN, MAX>